@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd3.4"
-#define HOST_OS_NAME "freebsd3"
-#define HOST_OS_VERSION "3.4"
+#define HOST_OS "freebsd4.0"
+#define HOST_OS_NAME "freebsd4"
+#define HOST_OS_VERSION "4.0"
 #define HOST_ARCH "i386"
-#define HOST_NAME "newt.mcl.cs.columbia.edu"
+#define HOST_NAME "elk.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 18:39:31 EDT 2000"
+#define CONFIG_DATE "Wed Apr  2 19:56:57 EST 1980"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "3.4"
+#define HOST_HEADER_VERSION "4.0"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -48,6 +48,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
 #define HAVE_SETITIMER 1
+#define HAVE_SETRESUID 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -252,15 +253,10 @@
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
-#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
-#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
-#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
-#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
-#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
@@ -287,6 +283,7 @@
 #define MOUNT_TYPE_CDFS "cd9660"
 #define MOUNT_TYPE_PCFS "msdos"
 #define MOUNT_TYPE_MFS "mfs"
+#define MOUNT_TYPE_IGNORE MNT_IGNORE
 #define MOUNT_TYPE_UNIONFS MNT_UNION
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs3"
@@ -296,6 +293,7 @@
 #define MNTTAB_TYPE_MFS "mfs"
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_IGNORE 0x800000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
@@ -325,5 +323,4 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
-#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
